@@ -1,8 +1,8 @@
 __title__ = 'pymia'
 __description__ = 'A Python package for data handling and evaluation in deep learning-based medical image analysis.'
 __url__ = 'https://pymia.readthedocs.io/'
-__version__ = '0.3.1'
+__version__ = '0.3.2'
 __author__ = 'Fabian Balsiger and Alain Jungo'
-__author_email__ = 'fabian.balsiger@artorg.unibe.ch'
+__author_email__ = 'fabian.balsiger@insel.ch'
 __license__ = 'Apache 2.0'
-__copyright__ = '2020 pymia authors'
+__copyright__ = '2020-2022 pymia authors'
