@@ -3,18 +3,21 @@
 The data augmentation bases on the transformation concept (see :class:`pymia.data.transformation.Transform`)
 and can easily be incorporated into the data loading process.
 
-Warnings:
-The augmentation relies on the random number generator of `numpy`. If you want to obtain reproducible result,
-set numpy's seed prior to executing any augmentation:
-
->>> import numpy as np
->>> your_seed = 0
->>> np.random.seed(your_seed)
-
 See Also:
-    https://github.com/MIC-DKFZ/batchgenerators
+    The pymia documentation features an code example for `Augmentation <https://pymia.readthedocs.io/en/latest/examples.augmentation.basic.html>`_,
+    which shows how to apply data augmentation in conjunction with the :mod:`pymia.data` package.
+    Besides transformations from the :mod:`pymia.data.augmentation` module, transformations from the Python packages `batchgenerators <https://github.com/MIC-DKFZ/batchgenerators>`_ and `TorchIO <https://github.com/fepegar/torchio/>`_ are integrated.
+
+Warnings:
+    The augmentation relies on the random number generator of ``numpy``. If you want to obtain reproducible result,
+    set numpy's seed prior to executing any augmentation:
+
+    >>> import numpy as np
+    >>> your_seed = 0
+    >>> np.random.seed(your_seed)
 """
 import typing
+import warnings
 
 import numpy as np
 import SimpleITK as sitk
@@ -89,7 +92,7 @@ class RandomCrop(tfm.Transform):
 
 class RandomElasticDeformation(tfm.Transform):
 
-    def __init__(self, num_control_points: int = 4, deformation_sigma=15,
+    def __init__(self, num_control_points: int = 4, deformation_sigma: float = 5.0,
                  interpolators: tuple = (sitk.sitkBSpline, sitk.sitkNearestNeighbor),
                  spatial_rank: int = 2, fill_value: float = 0.0,
                  p: float = 0.5, entries=(defs.KEY_IMAGES, defs.KEY_LABELS)):
@@ -103,7 +106,7 @@ class RandomElasticDeformation(tfm.Transform):
 
         Args:
             num_control_points (int): The number of control points for the b-spline mesh.
-            deformation_sigma: The maximum deformation along the deformation mesh.
+            deformation_sigma (float): The maximum deformation along the deformation mesh.
             interpolators (tuple): The SimpleITK interpolators to use for each entry in entries.
             spatial_rank (int): The spatial rank (dimension) of the sample.
             fill_value (float): The fill value for the resampling.
@@ -225,10 +228,11 @@ class RandomRotation90(tfm.Transform):
                 raise ValueError(tfm.ENTRY_NOT_EXTRACTED_ERR_MSG.format(entry))
 
             if sample[entry].shape[self.axes[0]] != sample[entry].shape[self.axes[1]]:
-                raise UserWarning('entry "{}" has unequal in-plane dimensions ({}, {}). \
-                Random 90 degree rotations might produce undesired results.'.format(entry,
-                                                                                    sample[entry].shape[self.axes[0]],
-                                                                                    sample[entry].shape[self.axes[1]]))
+                warnings.warn(f'entry "{entry}" has unequal in-plane dimensions ({sample[entry].shape[self.axes[0]]}, '
+                              f'{sample[entry].shape[self.axes[1]]}). '
+                              'Random 90 degree rotation might produce undesired results. Verify the output!',
+                              RuntimeWarning)
+
             sample[entry] = np.rot90(sample[entry], k, axes=self.axes).copy()
 
         return sample
