@@ -6,8 +6,8 @@ import pymia.data.extraction as extr
 class PytorchDatasetAdapter(torch_data.Dataset):
 
     def __init__(self, datasource: extr.PymiaDatasource) -> None:
-        """A wrapper class for :class:`.PymiaDatasource` to fit the `
-        torch.utils.data.Dataset <https://pytorch.org/docs/stable/data.html#torch.utils.data.Dataset>`_ interface.
+        """A wrapper class for :class:`.PymiaDatasource` to fit the
+        `torch.utils.data.Dataset <https://pytorch.org/docs/stable/data.html#torch.utils.data.Dataset>`_ interface.
 
         Args:
             datasource (.PymiaDatasource): The pymia datasource instance.
@@ -20,4 +20,4 @@ class PytorchDatasetAdapter(torch_data.Dataset):
         return len(self.datasource)
 
     def __getitem__(self, index: int):
-        return self.datasource[index]
\ No newline at end of file
+        return self.datasource[index]
