@@ -1,5 +1,5 @@
 from .callback import (Callback, MonitoringCallback, WriteDataCallback, WriteFilesCallback, WriteNamesCallback,
-                       WriteSubjectCallback, WriteImageInformationCallback, ComposeCallback, get_default_callbacks)
+                       WriteEssentialCallback, WriteImageInformationCallback, ComposeCallback, get_default_callbacks)
 from .fileloader import (Load, LoadDefault)
 from .writer import (Hdf5Writer, Writer, get_writer)
-from .traverser import (SubjectFileTraverser, Traverser)
+from .traverser import (Traverser)
