@@ -8,6 +8,7 @@ import SimpleITK as sitk
 
 import pymia.data.conversion as conv
 import pymia.data.definition as defs
+import pymia.data.extraction.byte_converter as byte_converter
 import pymia.data.indexexpression as expr
 from . import reader as rd
 
@@ -45,6 +46,7 @@ class ComposeExtractor(Extractor):
 
 
 class NamesExtractor(Extractor):
+
     def __init__(self, cache: bool = True, categories=(defs.KEY_IMAGES, defs.KEY_LABELS)) -> None:
         """Extracts the names of the entries within a category (e.g. "Flair", "T1" for the category "images").
 
@@ -71,7 +73,7 @@ class NamesExtractor(Extractor):
             d = self.cached_result
 
         for k, v in d.items():
-            extracted[k] = v
+            extracted[k] = byte_converter.convert_to_string(v)
 
     def _extract(self, reader: rd.Reader):
         d = {}
@@ -93,7 +95,7 @@ class SubjectExtractor(Extractor):
         """see :meth:`.Extractor.extract`"""
         extracted[defs.KEY_SUBJECT_INDEX] = params[defs.KEY_SUBJECT_INDEX]
         subject_index_expr = expr.IndexExpression(params[defs.KEY_SUBJECT_INDEX])
-        extracted[defs.KEY_SUBJECT] = reader.read(defs.LOC_SUBJECT, subject_index_expr)
+        extracted[defs.KEY_SUBJECT] = byte_converter.convert_to_string(reader.read(defs.LOC_SUBJECT, subject_index_expr))
 
 
 class IndexingExtractor(Extractor):
@@ -195,11 +197,11 @@ class FilesExtractor(Extractor):
         else:
             file_root = self.cached_file_root
 
-        extracted[defs.KEY_FILE_ROOT] = file_root
+        extracted[defs.KEY_FILE_ROOT] = byte_converter.convert_to_string(file_root)
 
         for category in self.categories:
-            extracted[defs.KEY_PLACEHOLDER_FILES.format(category)] = reader.read(defs.LOC_FILES_PLACEHOLDER.format(category),
-                                                                                 subject_index_expr)
+            extracted[defs.KEY_PLACEHOLDER_FILES.format(category)] = byte_converter.convert_to_string(
+                reader.read(defs.LOC_FILES_PLACEHOLDER.format(category), subject_index_expr))
 
 
 class SelectiveDataExtractor(Extractor):
@@ -207,15 +209,14 @@ class SelectiveDataExtractor(Extractor):
     def __init__(self, selection=None, category: str = defs.KEY_LABELS) -> None:
         """Extracts data of a given category selectively.
 
-        Adds :obj:`category` as key to :obj:`extracted`.
+        Adds :obj:`category` as key to :obj:`extracted`, as well as
+
+        - :const:`pymia.data.definition.KEY_PLACEHOLDER_NAMES_SELECTED` with :obj:`selection` content
 
         Args:
             selection (str, tuple): Entries (e.g., "T1", "T2") within the category to select.
                 If selection is None, the class has the same behaviour as the DataExtractor and selects all entries.
             category (str): The category (e.g. "images") to extract data from.
-
-        Note:
-            Requires results of :class:`NamesExtractor` in :obj:`extracted`.
         """
         super().__init__()
         self.subject_entries = None
@@ -225,29 +226,38 @@ class SelectiveDataExtractor(Extractor):
         self.selection = selection
         self.category = category
 
+        self.names_extractor = None  # used in case that the names of the entries of the category are not extracted
+
     def extract(self, reader: rd.Reader, params: dict, extracted: dict) -> None:
         """see :meth:`.Extractor.extract`"""
         if defs.KEY_PLACEHOLDER_NAMES.format(self.category) not in extracted:
-            raise ValueError('selection of labels requires label_names to be extracted (use NamesExtractor)')
+            if self.names_extractor is None:
+                self.names_extractor = NamesExtractor(cache=True, categories=(self.category, ))
+            self.names_extractor.extract(reader, {}, extracted)
 
         if self.subject_entries is None:
             self.subject_entries = reader.get_subject_entries()
 
         if not reader.has(defs.LOC_DATA_PLACEHOLDER.format(self.category)):
-            raise ValueError('SelectiveDataExtractor requires {} to exist'.format(self.category))
+            raise ValueError(f'SelectiveDataExtractor requires {self.category} to exist')
 
         subject_index = params[defs.KEY_SUBJECT_INDEX]
         index_expr = params[defs.KEY_INDEX_EXPR]
 
         index_str = self.subject_entries[subject_index]
         data = reader.read('{}/{}'.format(defs.LOC_DATA_PLACEHOLDER.format(self.category), index_str), index_expr)
-        label_names = extracted[defs.KEY_PLACEHOLDER_NAMES.format(self.category)]  # type: list
+        entry_names = extracted[defs.KEY_PLACEHOLDER_NAMES.format(self.category)]  # type: list
 
         if self.selection is None:
-            extracted[self.category] = data
+            extracted[self.category] = byte_converter.convert_to_string(data)
         else:
-            selection_indices = np.array([label_names.index(s) for s in self.selection])
+            selection_indices = np.array([entry_names.index(s) for s in self.selection])
             extracted[self.category] = np.take(data, selection_indices, axis=-1)
+            if isinstance(data, list):
+                # convert back to list
+                extracted[self.category] = byte_converter.convert_to_string(extracted[self.category].tolist())
+
+            extracted[defs.KEY_PLACEHOLDER_NAMES_SELECTED.format(self.category)] = list(self.selection)
 
 
 class RandomDataExtractor(Extractor):
@@ -257,13 +267,12 @@ class RandomDataExtractor(Extractor):
 
         Adds :obj:`category` as key to :obj:`extracted`.
 
+        - :const:`pymia.data.definition.KEY_PLACEHOLDER_NAMES_SELECTED` with :obj:`selection` content
+
         Args:
             selection (str, tuple): Entries (e.g., "T1", "T2") within the category to select an entry randomly from.
                 If selection is None, an entry from all entries is randomly selected.
             category (str): The category (e.g. "images") to extract data from.
-
-        Note:
-            Requires results of :class:`NamesExtractor` in :obj:`extracted`.
         """
         super().__init__()
         self.subject_entries = None
@@ -273,31 +282,39 @@ class RandomDataExtractor(Extractor):
         self.selection = selection
         self.category = category
 
+        self.names_extractor = None  # used in case that the names of the entries of the category are not extracted
+
     def extract(self, reader: rd.Reader, params: dict, extracted: dict) -> None:
         """see :meth:`.Extractor.extract`"""
         if defs.KEY_PLACEHOLDER_NAMES.format(self.category) not in extracted:
-            raise ValueError('selection of labels requires label_names to be extracted (use NamesExtractor)')
+            if self.names_extractor is None:
+                self.names_extractor = NamesExtractor(cache=True, categories=(self.category,))
+            self.names_extractor.extract(reader, {}, extracted)
 
         if self.subject_entries is None:
             self.subject_entries = reader.get_subject_entries()
 
         if not reader.has(defs.LOC_DATA_PLACEHOLDER.format(self.category)):
-            raise ValueError('SelectiveDataExtractor requires {} to exist'.format(self.category))
+            raise ValueError(f'SelectiveDataExtractor requires {self.category} to exist')
 
         subject_index = params[defs.KEY_SUBJECT_INDEX]
         index_expr = params[defs.KEY_INDEX_EXPR]
 
         index_str = self.subject_entries[subject_index]
         data = reader.read('{}/{}'.format(defs.LOC_DATA_PLACEHOLDER.format(self.category), index_str), index_expr)
-        label_names = extracted[defs.KEY_PLACEHOLDER_NAMES.format(self.category)]  # type: list
+        entry_names = extracted[defs.KEY_PLACEHOLDER_NAMES.format(self.category)]  # type: list
 
         if self.selection is None:
-            selection_indices = np.array(range(len(label_names)))
+            selection_indices = np.array(range(len(entry_names)))
         else:
-            selection_indices = np.array([label_names.index(s) for s in self.selection])
+            selection_indices = np.array([entry_names.index(s) for s in self.selection])
 
         random_index = [np.random.choice(selection_indices)]  # as list to keep the last dimension with np.take
         extracted[self.category] = np.take(data, random_index, axis=-1)
+        if isinstance(data, list):
+            # convert back to list
+            extracted[self.category] = byte_converter.convert_to_string(extracted[self.category].tolist())
+        extracted[defs.KEY_PLACEHOLDER_NAMES_SELECTED.format(self.category)] = [entry_names[random_index[0]]]
 
 
 class ImagePropertyShapeExtractor(Extractor):
@@ -359,7 +376,7 @@ class DataExtractor(Extractor):
                 data = reader.read('{}/{}'.format(defs.LOC_DATA_PLACEHOLDER.format(category), index_str))
             else:
                 data = reader.read('{}/{}'.format(defs.LOC_DATA_PLACEHOLDER.format(category), index_str), index_expr)
-            extracted[category] = data
+            extracted[category] = byte_converter.convert_to_string(data)
 
 
 class PadDataExtractor(Extractor):
@@ -466,12 +483,12 @@ class FilesystemDataExtractor(Extractor):
         subject_index_expr = expr.IndexExpression(params[defs.KEY_SUBJECT_INDEX])
 
         if self.cached_file_root is None:
-            self.cached_file_root = reader.read(defs.LOC_FILES_ROOT)
+            self.cached_file_root = byte_converter.convert_to_string(reader.read(defs.LOC_FILES_ROOT))
 
         file_root = self.cached_file_root
 
         for category in self.categories:
-            rel_file_paths = reader.read(defs.LOC_FILES_PLACEHOLDER.format(category), subject_index_expr)
+            rel_file_paths = byte_converter.convert_to_string(reader.read(defs.LOC_FILES_PLACEHOLDER.format(category), subject_index_expr))
 
             loaded = []
             for rel_file_path in rel_file_paths:
@@ -481,3 +498,4 @@ class FilesystemDataExtractor(Extractor):
             if not self.ignore_indexing:
                 data = data[index_expr.expression]
             extracted[category] = data
+
