@@ -1,3 +1,6 @@
+""""""
+
+
 class FileCategory:
     def __init__(self, entries=None) -> None:
         if entries is None:
@@ -8,6 +11,12 @@ class FileCategory:
 class SubjectFile:
 
     def __init__(self, subject: str, **file_groups) -> None:
+        """Holds the file information of a subject.
+
+        Args:
+            subject (str): The subject identifier.
+            **file_groups (dict): The groups of file types containing the file path entries.
+        """
         self.subject = subject
         self.categories = {}
         for category_name, category_files in file_groups.items():
@@ -23,6 +32,11 @@ class SubjectFile:
             raise ValueError('Identifiers must be unique')
 
     def get_all_files(self):
+        """
+        Returns:
+            dict: All file path entries of a subject `flattened` (without groups/category).
+
+        """
         all_files = {}
         for file_category in self.categories.values():
             for id_, filename in file_category.entries.items():
